@@ -21,9 +21,9 @@ namespace Tellico {
 /**
  * @author Robby Stephenson
  */
-class FieldCompletion : public KCompletion {
+class FieldCompletion : public TDECompletion {
 Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
   FieldCompletion(bool multiple);
@@ -35,7 +35,7 @@ public:
 protected:
   virtual void postProcessMatch(TQString* match) const;
   virtual void postProcessMatches(TQStringList* matches) const;
-  virtual void postProcessMatches(KCompletionMatches* matches) const;
+  virtual void postProcessMatches(TDECompletionMatches* matches) const;
 
 private:
   bool m_multiple;
